## Contributing to this package
This package is open to contributions. 

To contribute, please follow these steps:

- Fork the upstream rscase repository into a personal account.
- Create a new branch for you changes
- Push the topic branch to your personal fork.
- Create a pull request to the rscase repository with an explanation of your changes.